@@ -52,8 +52,8 @@ typedef unsigned char     uint8_t;	/* 8-bit int */
   typedef unsigned  short  uint16_t;	/* 16-bit int */
   typedef   signed  int   int32_t;	/* 32-bit int */
   typedef unsigned  int  uint32_t;	/* 32-bit int */
-  typedef   signed  long long   int64_t;	/* 64-bit int */
-  typedef unsigned  long long  uint64_t;	/* 64-bit int */
+  typedef   signed  long   int64_t;	/* 64-bit int */
+  typedef unsigned  long  uint64_t;	/* 64-bit int */
 #  endif
 #endif
 
